CliAction

Enum CliAction 

pub enum CliAction {
Show 72 variants Write { bytes: Vec<u8>, pane_id: Option<String>, }, WriteChars { chars: String, pane_id: Option<String>, }, Paste { chars: String, pane_id: Option<String>, }, SendKeys { keys: Vec<String>, pane_id: Option<String>, }, Resize { resize: Resize, direction: Option<Direction>, pane_id: Option<String>, }, FocusNextPane, FocusPreviousPane, FocusPaneId { pane_id: String, }, MoveFocus { direction: Direction, }, MoveFocusOrTab { direction: Direction, }, MovePane { direction: Option<Direction>, pane_id: Option<String>, }, MovePaneBackwards { pane_id: Option<String>, }, Clear { pane_id: Option<String>, }, DumpScreen { path: Option<PathBuf>, full: bool, pane_id: Option<String>, ansi: bool, }, DumpLayout, SaveSession, EditScrollback { pane_id: Option<String>, ansi: bool, }, ScrollUp { pane_id: Option<String>, }, ScrollDown { pane_id: Option<String>, }, ScrollToBottom { pane_id: Option<String>, }, ScrollToTop { pane_id: Option<String>, }, PageScrollUp { pane_id: Option<String>, }, PageScrollDown { pane_id: Option<String>, }, HalfPageScrollUp { pane_id: Option<String>, }, HalfPageScrollDown { pane_id: Option<String>, }, ToggleFullscreen { pane_id: Option<String>, }, TogglePaneFrames, ToggleActiveSyncTab { tab_id: Option<usize>, }, NewPane {
Show 26 fields direction: Option<Direction>, command: Vec<String>, plugin: Option<String>, cwd: Option<PathBuf>, floating: bool, in_place: bool, close_replaced_pane: bool, name: Option<String>, close_on_exit: bool, start_suspended: bool, configuration: Option<PluginUserConfiguration>, skip_plugin_cache: bool, x: Option<String>, y: Option<String>, width: Option<String>, height: Option<String>, pinned: Option<bool>, stacked: bool, blocking: bool, block_until_exit_success: bool, block_until_exit_failure: bool, block_until_exit: bool, unblock_condition: Option<UnblockCondition>, near_current_pane: bool, borderless: Option<bool>, tab_id: Option<usize>,
}, Edit {
Show 15 fields file: PathBuf, direction: Option<Direction>, line_number: Option<usize>, floating: bool, in_place: bool, close_replaced_pane: bool, cwd: Option<PathBuf>, x: Option<String>, y: Option<String>, width: Option<String>, height: Option<String>, pinned: Option<bool>, near_current_pane: bool, borderless: Option<bool>, tab_id: Option<usize>,
}, SwitchMode { input_mode: InputMode, }, TogglePaneEmbedOrFloating { pane_id: Option<String>, }, ToggleFloatingPanes { tab_id: Option<usize>, }, ShowFloatingPanes { tab_id: Option<usize>, }, HideFloatingPanes { tab_id: Option<usize>, }, AreFloatingPanesVisible { tab_id: Option<usize>, }, ClosePane { pane_id: Option<String>, }, RenamePane { name: String, pane_id: Option<String>, }, UndoRenamePane { pane_id: Option<String>, }, GoToNextTab, GoToPreviousTab, CloseTab { tab_id: Option<usize>, }, GoToTab { index: u32, }, GoToTabName { name: String, create: bool, }, RenameTab { name: String, tab_id: Option<usize>, }, UndoRenameTab { tab_id: Option<usize>, }, GoToTabById { id: u64, }, CloseTabById { id: u64, }, RenameTabById { id: u64, name: String, }, NewTab { layout: Option<PathBuf>, layout_string: Option<String>, layout_dir: Option<PathBuf>, name: Option<String>, cwd: Option<PathBuf>, initial_command: Vec<String>, initial_plugin: Option<String>, close_on_exit: bool, start_suspended: bool, block_until_exit_success: bool, block_until_exit_failure: bool, block_until_exit: bool, }, MoveTab { direction: Direction, tab_id: Option<usize>, }, PreviousSwapLayout { tab_id: Option<usize>, }, NextSwapLayout { tab_id: Option<usize>, }, OverrideLayout { layout: Option<PathBuf>, layout_string: Option<String>, layout_dir: Option<PathBuf>, retain_existing_terminal_panes: bool, retain_existing_plugin_panes: bool, apply_only_to_active_tab: bool, }, QueryTabNames, StartOrReloadPlugin { url: String, configuration: Option<PluginUserConfiguration>, }, LaunchOrFocusPlugin { floating: bool, in_place: bool, close_replaced_pane: bool, move_to_focused_tab: bool, url: String, configuration: Option<PluginUserConfiguration>, skip_plugin_cache: bool, tab_id: Option<usize>, }, LaunchPlugin { floating: bool, in_place: bool, close_replaced_pane: bool, url: Url, configuration: Option<PluginUserConfiguration>, skip_plugin_cache: bool, tab_id: Option<usize>, }, RenameSession { name: String, }, Pipe { name: Option<String>, payload: Option<String>, args: Option<PluginUserConfiguration>, plugin: Option<String>, plugin_configuration: Option<PluginUserConfiguration>, force_launch_plugin: bool, skip_plugin_cache: bool, floating_plugin: Option<bool>, in_place_plugin: Option<bool>, plugin_cwd: Option<PathBuf>, plugin_title: Option<String>, }, ListClients, ListPanes { tab: bool, command: bool, state: bool, geometry: bool, all: bool, json: bool, }, ListTabs { state: bool, dimensions: bool, panes: bool, layout: bool, all: bool, json: bool, }, CurrentTabInfo { json: bool, }, TogglePanePinned { pane_id: Option<String>, }, StackPanes { pane_ids: Vec<String>, }, ChangeFloatingPaneCoordinates { pane_id: String, x: Option<String>, y: Option<String>, width: Option<String>, height: Option<String>, pinned: Option<bool>, borderless: Option<bool>, }, TogglePaneBorderless { pane_id: String, }, SetPaneBorderless { pane_id: String, borderless: bool, }, Detach, SwitchSession { name: String, tab_position: Option<usize>, pane_id: Option<String>, layout: Option<PathBuf>, layout_string: Option<String>, layout_dir: Option<PathBuf>, cwd: Option<PathBuf>, }, SetPaneColor { pane_id: Option<String>, fg: Option<String>, bg: Option<String>, reset: bool, },
}

Variants



Write

Write bytes to the terminal.

Fields

bytes: Vec<u8>
pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)



WriteChars

Write characters to the terminal.

Fields

chars: String
pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)



Paste

Paste text to the terminal (using bracketed paste mode).

Fields

chars: String
pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)



SendKeys

Send one or more keys to the terminal (e.g., “Ctrl a”, “F1”, “Alt Shift b”)

Fields

keys: Vec<String>

Keys to send as space-separated strings

pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)



Resize

[increase|decrease] the focused panes area at the [left|down|up|right] border.

Fields

resize: Resize
direction: Option<Direction>
pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



FocusNextPane

Change focus to the next pane



FocusPreviousPane

Change focus to the previous pane



FocusPaneId

Focus a specific pane by its ID

Fields

pane_id: String

The pane_id of the pane, eg. terminal_1, plugin_2 or 3



MoveFocus

Move the focused pane in the specified direction. [right|left|up|down]

Fields

direction: Direction


MoveFocusOrTab

Move focus to the pane or tab (if on screen edge) in the specified direction [right|left|up|down]

Fields

direction: Direction


MovePane

Change the location of the focused pane in the specified direction or rotate forwrads [right|left|up|down]

Fields

direction: Option<Direction>
pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



MovePaneBackwards

Rotate the location of the previous pane backwards

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



Clear

Clear all buffers for a focused pane

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



DumpScreen

Dumps the viewport and optionally scrollback of a pane to a file or STDOUT

Fields

path: Option<PathBuf>

File path to dump the pane content to. If omitted, prints to STDOUT.

full: bool

Dump the pane with full scrollback

pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3). If not specified, dumps the focused pane.

ansi: bool

Preserve ANSI styling in the dump output



DumpLayout

Dump current layout to stdout



SaveSession

Save the current session state to disk immediately



EditScrollback

Open the pane scrollback in your default editor

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)

ansi: bool

Preserve ANSI styling in the scrollback dump



ScrollUp

Scroll up in the focused pane

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



ScrollDown

Scroll down in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



ScrollToBottom

Scroll down to bottom in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



ScrollToTop

Scroll up to top in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



PageScrollUp

Scroll up one page in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



PageScrollDown

Scroll down one page in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



HalfPageScrollUp

Scroll up half page in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



HalfPageScrollDown

Scroll down half page in focus pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



ToggleFullscreen

Toggle between fullscreen focus pane and normal layout.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



TogglePaneFrames

Toggle frames around panes in the UI



ToggleActiveSyncTab

Toggle between sending text commands to all panes on the current tab and normal mode.

Fields

tab_id: Option<usize>

Target a specific tab by ID



NewPane

Open a new pane in the specified direction [right|down] If no direction is specified, will try to use the biggest available space. Returns: Created pane ID (format: terminal_ or plugin_)

Fields

direction: Option<Direction>

Direction to open the new pane in

command: Vec<String>
plugin: Option<String>
cwd: Option<PathBuf>

Change the working directory of the new pane

floating: bool

Open the new pane in floating mode

in_place: bool

Open the new pane in place of the current pane, temporarily suspending it

close_replaced_pane: bool

Close the replaced pane instead of suspending it (only effective with –in-place)

name: Option<String>

Name of the new pane

close_on_exit: bool

Close the pane immediately when its command exits

start_suspended: bool

Start the command suspended, only running it after the you first press ENTER

skip_plugin_cache: bool
x: Option<String>

The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

y: Option<String>

The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

width: Option<String>

The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

height: Option<String>

The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

pinned: Option<bool>

Whether to pin a floating pane so that it is always on top

stacked: bool
blocking: bool

Block until the command has finished and its pane has been closed

block_until_exit_success: bool

Block until the command exits successfully (exit status 0) OR its pane has been closed

block_until_exit_failure: bool

Block until the command exits with failure (non-zero exit status) OR its pane has been closed

block_until_exit: bool

Block until the command exits (regardless of exit status) OR its pane has been closed

unblock_condition: Option<UnblockCondition>
near_current_pane: bool

if set, will open the pane near the current one rather than following the user’s focus

borderless: Option<bool>

start this pane without a border (warning: will make it impossible to move with the mouse)

tab_id: Option<usize>

Target a specific tab by ID



Edit

Open the specified file in a new zellij pane with your default EDITOR Returns: Created pane ID (format: terminal_)

Fields

file: PathBuf
direction: Option<Direction>

Direction to open the new pane in

line_number: Option<usize>

Open the file in the specified line number

floating: bool

Open the new pane in floating mode

in_place: bool

Open the new pane in place of the current pane, temporarily suspending it

close_replaced_pane: bool

Close the replaced pane instead of suspending it (only effective with –in-place)

cwd: Option<PathBuf>

Change the working directory of the editor

x: Option<String>

The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

y: Option<String>

The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

width: Option<String>

The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

height: Option<String>

The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

pinned: Option<bool>

Whether to pin a floating pane so that it is always on top

near_current_pane: bool

if set, will open the pane near the current one rather than following the user’s focus

borderless: Option<bool>

start this pane without a border (warning: will make it impossible to move with the mouse)

tab_id: Option<usize>

Target a specific tab by ID



SwitchMode

Switch input mode of all connected clients [locked|pane|tab|resize|move|search|session]

Fields

input_mode: InputMode


TogglePaneEmbedOrFloating

Embed focused pane if floating or float focused pane if embedded

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



ToggleFloatingPanes

Toggle the visibility of all floating panes in the current Tab, open one if none exist

Fields

tab_id: Option<usize>

Target a specific tab by ID



ShowFloatingPanes

Show all floating panes in the specified tab (or active tab if tab_id is not provided).

Returns exit code 0 if state was changed, 2 if already visible, 1 if tab not found.

Fields

tab_id: Option<usize>


HideFloatingPanes

Hide all floating panes in the specified tab (or active tab if tab_id is not provided).

Returns exit code 0 if state was changed, 2 if already hidden, 1 if tab not found.

Fields

tab_id: Option<usize>


AreFloatingPanesVisible

Check if floating panes are visible in the specified tab (or active tab).

Prints “true” to stdout and exits 0 if visible. Prints “false” to stdout and exits 1 if not visible.

Fields

tab_id: Option<usize>


ClosePane

Close the focused pane.

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



RenamePane

Renames the focused pane

Fields

name: String
pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



UndoRenamePane

Remove a previously set pane name

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



GoToNextTab

Go to the next tab.



GoToPreviousTab

Go to the previous tab.



CloseTab

Close the current tab.

Fields

tab_id: Option<usize>

Target a specific tab by ID



GoToTab

Go to tab with index [index]

Fields

index: u32


GoToTabName

Go to tab with name [name]

Returns: When –create is used and tab is created, outputs the tab ID as a single number

Fields

name: String
create: bool

Create a tab if one does not exist.



RenameTab

Renames the focused pane

Fields

name: String
tab_id: Option<usize>

Target a specific tab by ID



UndoRenameTab

Remove a previously set tab name

Fields

tab_id: Option<usize>

Target a specific tab by ID



GoToTabById

Go to tab with stable ID

Fields

id: u64


CloseTabById

Close tab with stable ID

Fields

id: u64


RenameTabById

Rename tab by stable ID

Fields

id: u64
name: String


NewTab

Create a new tab, optionally with a specified tab layout and name

Returns: The created tab’s ID as a single number on stdout

Fields

layout: Option<PathBuf>

Layout to use for the new tab

layout_string: Option<String>

Raw KDL layout string to use directly (instead of a layout file path)

layout_dir: Option<PathBuf>

Default folder to look for layouts

name: Option<String>

Name of the new tab

cwd: Option<PathBuf>

Change the working directory of the new tab

initial_command: Vec<String>

Optional initial command to run in the new tab

initial_plugin: Option<String>

Initial plugin to load in the new tab

close_on_exit: bool

Close the pane immediately when its command exits

start_suspended: bool

Start the command suspended, only running it after you first press ENTER

block_until_exit_success: bool

Block until the command exits successfully (exit status 0) OR its pane has been closed

block_until_exit_failure: bool

Block until the command exits with failure (non-zero exit status) OR its pane has been closed

block_until_exit: bool

Block until the command exits (regardless of exit status) OR its pane has been closed



MoveTab

Move the focused tab in the specified direction. [right|left]

Fields

direction: Direction
tab_id: Option<usize>

Target a specific tab by ID



PreviousSwapLayout

Fields

tab_id: Option<usize>

Target a specific tab by ID



NextSwapLayout

Fields

tab_id: Option<usize>

Target a specific tab by ID



OverrideLayout

Override the layout of the active tab

Fields

layout: Option<PathBuf>

Path to the layout file

layout_string: Option<String>

Raw KDL layout string to use directly (instead of a layout file path)

layout_dir: Option<PathBuf>

Default folder to look for layouts

retain_existing_terminal_panes: bool

Retain existing terminal panes that do not fit in the layout (default: false)

retain_existing_plugin_panes: bool

Retain existing plugin panes that do not fit with the layout default: false)

apply_only_to_active_tab: bool

Only apply the layout to the active tab (uses just the first layout tab if it has multiple)



QueryTabNames

Query all tab names



StartOrReloadPlugin

Fields



LaunchOrFocusPlugin

Returns: Plugin pane ID (format: plugin_) when creating or focusing plugin

Fields

floating: bool
in_place: bool
close_replaced_pane: bool

Close the replaced pane instead of suspending it (only effective with –in-place)

move_to_focused_tab: bool
skip_plugin_cache: bool
tab_id: Option<usize>

Target a specific tab by ID



LaunchPlugin

Returns: Plugin pane ID (format: plugin_)

Fields

floating: bool
in_place: bool
close_replaced_pane: bool

Close the replaced pane instead of suspending it (only effective with –in-place)

url: Url
skip_plugin_cache: bool
tab_id: Option<usize>

Target a specific tab by ID



RenameSession

Fields

name: String


Pipe

Send data to one or more plugins, launch them if they are not running.

Fields

name: Option<String>

The name of the pipe

payload: Option<String>

The data to send down this pipe (if blank, will listen to STDIN)

args: Option<PluginUserConfiguration>

The args of the pipe

plugin: Option<String>

The plugin url (eg. file:/tmp/my-plugin.wasm) to direct this pipe to, if not specified, will be sent to all plugins, if specified and is not running, the plugin will be launched

plugin_configuration: Option<PluginUserConfiguration>

The plugin configuration (note: the same plugin with different configuration is considered a different plugin for the purposes of determining the pipe destination)

force_launch_plugin: bool

Launch a new plugin even if one is already running

skip_plugin_cache: bool

If launching a new plugin, skip cache and force-compile the plugin

floating_plugin: Option<bool>

If launching a plugin, should it be floating or not, defaults to floating

in_place_plugin: Option<bool>

If launching a plugin, launch it in-place (on top of the current pane)

plugin_cwd: Option<PathBuf>

If launching a plugin, specify its working directory

plugin_title: Option<String>

If launching a plugin, specify its pane title



ListClients



ListPanes

List all panes in the current session

Returns: Formatted list of panes (table or JSON) to stdout

Fields

tab: bool

Include tab information (name, position, ID)

command: bool

Include running command information

state: bool

Include pane state (focused, floating, exited, etc.)

geometry: bool

Include geometry (position, size)

all: bool

Include all available fields

json: bool

Output as JSON



ListTabs

List all tabs with their information

Returns: Tab information in table or JSON format

Fields

state: bool

Include state information (active, fullscreen, sync, floating visibility)

dimensions: bool

Include dimension information (viewport, display area)

panes: bool

Include pane counts

layout: bool

Include layout information (swap layout name and dirty state)

all: bool

Include all available fields

json: bool

Output as JSON



CurrentTabInfo

Get information about the currently active tab

Returns: Tab name and ID by default, or full info in JSON

Fields

json: bool

Output as JSON with full TabInfo



TogglePanePinned

Fields

pane_id: Option<String>

Target a specific pane by ID (eg. terminal_1, plugin_2, or 3)



StackPanes

Stack pane ids Ids are a space separated list of pane ids. They should either be in the form of terminal_<int> (eg. terminal_1), plugin_<int> (eg. plugin_1) or bare integers in which case they’ll be considered terminals (eg. 1 is the equivalent of terminal_1)

Example: zellij action stack-panes – terminal_1 plugin_2 3

Fields

pane_ids: Vec<String>


ChangeFloatingPaneCoordinates

Fields

pane_id: String

The pane_id of the floating pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)

x: Option<String>

The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

y: Option<String>

The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

width: Option<String>

The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

height: Option<String>

The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)

pinned: Option<bool>

Whether to pin a floating pane so that it is always on top

borderless: Option<bool>

change this pane to be with/without a border (warning: will make it impossible to move with the mouse if without a border)



TogglePaneBorderless

Fields

pane_id: String

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)



SetPaneBorderless

Fields

pane_id: String

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)

borderless: bool

Whether the pane should be borderless (flag present) or bordered (flag absent)



Detach

Detach from the current session



SwitchSession

Switch to a different session

Fields

name: String

Name of the session to switch to

tab_position: Option<usize>

Optional tab position to focus

pane_id: Option<String>

Optional pane ID to focus (eg. “terminal_1” for terminal pane with id 1, or “plugin_2” for plugin pane with id 2)

layout: Option<PathBuf>

Layout to apply when switching to the session (relative paths start at layout-dir)

layout_string: Option<String>

Raw KDL layout string to use directly

layout_dir: Option<PathBuf>

Default folder to look for layouts

cwd: Option<PathBuf>

Change the working directory when switching



SetPaneColor

Set the default foreground/background color of a pane

Fields

pane_id: Option<String>

The pane_id of the pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3). Defaults to $ZELLIJ_PANE_ID if not provided.

fg: Option<String>

Foreground color (e.g. “#00e000”, “rgb:00/e0/00”)

bg: Option<String>

Background color (e.g. “#001a3a”, “rgb:00/1a/3a”)

reset: bool

Reset pane colors to terminal defaults