pub enum Sessions {
Show 15 variants
ListSessions {
no_formatting: bool,
short: bool,
reverse: bool,
},
ListAliases,
Attach {
session_name: Option<String>,
create: bool,
create_background: bool,
index: Option<usize>,
options: Option<Box<SessionCommand>>,
force_run_commands: bool,
token: Option<String>,
remember: bool,
forget: bool,
ca_cert: Option<PathBuf>,
insecure: bool,
},
Watch {
session_name: Option<String>,
},
KillSession {
target_session: Option<String>,
},
DeleteSession {
target_session: Option<String>,
force: bool,
},
KillAllSessions {
yes: bool,
},
DeleteAllSessions {
yes: bool,
force: bool,
},
Run {Show 22 fields
command: Vec<String>,
direction: Option<Direction>,
cwd: Option<PathBuf>,
floating: bool,
in_place: bool,
close_replaced_pane: bool,
name: Option<String>,
close_on_exit: bool,
start_suspended: bool,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
stacked: bool,
blocking: bool,
block_until_exit_success: bool,
block_until_exit_failure: bool,
block_until_exit: bool,
near_current_pane: bool,
borderless: Option<bool>,
tab_id: Option<usize>,
},
Plugin {Show 13 fields
url: String,
configuration: Option<PluginUserConfiguration>,
floating: bool,
in_place: bool,
close_replaced_pane: bool,
skip_plugin_cache: bool,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
borderless: Option<bool>,
tab_id: Option<usize>,
},
Edit {Show 15 fields
file: PathBuf,
line_number: Option<usize>,
direction: Option<Direction>,
in_place: bool,
close_replaced_pane: bool,
floating: bool,
cwd: Option<PathBuf>,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
near_current_pane: bool,
borderless: Option<bool>,
tab_id: Option<usize>,
},
ConvertConfig {
old_config_file: PathBuf,
},
ConvertLayout {
old_layout_file: PathBuf,
},
ConvertTheme {
old_theme_file: PathBuf,
},
Pipe {
name: Option<String>,
payload: Option<String>,
args: Option<PluginUserConfiguration>,
plugin: Option<String>,
plugin_configuration: Option<PluginUserConfiguration>,
},
}Variants
ListSessions
List active sessions
Fields
ListAliases
List existing plugin aliases
Attach
Attach to a session
Fields
options: Option<Box<SessionCommand>>Change the behaviour of zellij
force_run_commands: boolIf resurrecting a dead session, immediately run all its commands on startup
Watch
Watch a session (read-only)
KillSession
Kill a specific session
DeleteSession
Delete a specific session
Fields
KillAllSessions
Kill all sessions
DeleteAllSessions
Delete all sessions
Fields
Run
Run a command in a new pane
Returns: Created pane ID (format: terminal_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
height: Option<String>The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
block_until_exit_success: boolBlock until the command exits successfully (exit status 0) OR its pane has been closed
block_until_exit_failure: boolBlock until the command exits with failure (non-zero exit status) OR its pane has been closed
block_until_exit: boolBlock until the command exits (regardless of exit status) OR its pane has been closed
near_current_pane: boolif set, will open the pane near the current one rather than following the user’s focus
Plugin
Load a plugin
Returns: Created pane ID (format: plugin_
Fields
configuration: Option<PluginUserConfiguration>Plugin configuration
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
skip_plugin_cache: boolSkip the memory and HD cache and force recompile of the plugin (good for development)
x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
height: Option<String>The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
Edit
Edit file with default $EDITOR / $VISUAL
Returns: Created pane ID (format: terminal_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
height: Option<String>The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
near_current_pane: boolif set, will open the pane near the current one rather than following the user’s focus
ConvertConfig
ConvertLayout
ConvertTheme
Pipe
Send data to one or more plugins, launch them if they are not running.
Fields
args: Option<PluginUserConfiguration>The args of the pipe
plugin: Option<String>The plugin url (eg. file:/tmp/my-plugin.wasm) to direct this pipe to, if not specified, will be sent to all plugins, if specified and is not running, the plugin will be launched
plugin_configuration: Option<PluginUserConfiguration>The plugin configuration (note: the same plugin with different configuration is considered a different plugin for the purposes of determining the pipe destination)