pub struct WebCli {Show 16 fields
pub start: bool,
pub stop: bool,
pub status: bool,
pub timeout: Option<u64>,
pub daemonize: bool,
pub server_startup_timeout: Option<u64>,
pub create_token: bool,
pub token_name: Option<String>,
pub create_read_only_token: bool,
pub revoke_token: Option<String>,
pub revoke_all_tokens: bool,
pub list_tokens: bool,
pub ip: Option<IpAddr>,
pub port: Option<u16>,
pub cert: Option<PathBuf>,
pub key: Option<PathBuf>,
}Fields
start: boolStart the server (default unless other arguments are specified)
stop: boolStop the server
status: boolGet the server status
timeout: Option<u64>Timeout in seconds for the status check (default: 30)
daemonize: boolRun the server in the background
server_startup_timeout: Option<u64>Timeout in seconds waiting for the server to start (default: 10). Only used on Windows where the daemonized server is polled via TCP. On Unix, startup signaling uses pipes and this option is ignored.
create_token: boolCreate a login token for the web interface, will only be displayed once and cannot later be retrieved. Returns the token name and the token.
token_name: Option<String>Optional name for the token
create_read_only_token: boolCreate a read-only login token (can only attach to existing sessions as watcher)
revoke_token: Option<String>Revoke a login token by its name
revoke_all_tokens: boolRevoke all login tokens
list_tokens: boolList token names and their creation dates (cannot show actual tokens)
ip: Option<IpAddr>The ip address to listen on locally for connections (defaults to 127.0.0.1)
port: Option<u16>The port to listen on locally for connections (defaults to 8082)
cert: Option<PathBuf>The path to the SSL certificate (required if not listening on 127.0.0.1)
key: Option<PathBuf>The path to the SSL key (required if not listening on 127.0.0.1)
Implementations