pub enum EventType {
Show 44 variants
ModeUpdate,
TabUpdate,
PaneUpdate,
Key,
Mouse,
Timer,
CopyToClipboard,
SystemClipboardFailure,
InputReceived,
Visible,
CustomMessage,
FileSystemCreate,
FileSystemRead,
FileSystemUpdate,
FileSystemDelete,
PermissionRequestResult,
SessionUpdate,
RunCommandResult,
WebRequestResult,
CommandPaneOpened,
CommandPaneExited,
PaneClosed,
EditPaneOpened,
EditPaneExited,
CommandPaneReRun,
FailedToWriteConfigToDisk,
ListClients,
HostFolderChanged,
FailedToChangeHostFolder,
PastedText,
ConfigWasWrittenToDisk,
WebServerStatus,
FailedToStartWebServer,
BeforeClose,
InterceptedKeyPress,
UserAction,
PaneRenderReport,
PaneRenderReportWithAnsi,
ActionComplete,
CwdChanged,
AvailableLayoutInfo,
PluginConfigurationChanged,
HighlightClicked,
InitialKeybinds,
}Variants
ModeUpdate
TabUpdate
PaneUpdate
Key
A key was pressed while the user is focused on this plugin’s pane
Mouse
A mouse event happened while the user is focused on this plugin’s pane
Timer
A timer expired set by the set_timeout method exported by zellij-tile.
CopyToClipboard
Text was copied to the clipboard anywhere in the app
SystemClipboardFailure
Failed to copy text to clipboard anywhere in the app
InputReceived
Input was received anywhere in the app
Visible
This plugin became visible or invisible
CustomMessage
A message from one of the plugin’s workers
FileSystemCreate
A file was created somewhere in the Zellij CWD folder
FileSystemRead
A file was accessed somewhere in the Zellij CWD folder
FileSystemUpdate
A file was modified somewhere in the Zellij CWD folder
FileSystemDelete
A file was deleted somewhere in the Zellij CWD folder
PermissionRequestResult
A Result of plugin permission request
SessionUpdate
RunCommandResult
WebRequestResult
CommandPaneOpened
CommandPaneExited
PaneClosed
EditPaneOpened
EditPaneExited
CommandPaneReRun
FailedToWriteConfigToDisk
ListClients
HostFolderChanged
FailedToChangeHostFolder
PastedText
ConfigWasWrittenToDisk
WebServerStatus
FailedToStartWebServer
BeforeClose
InterceptedKeyPress
UserAction
An action was performed by the user (requires InterceptInput permission)
PaneRenderReport
PaneRenderReportWithAnsi
ActionComplete
CwdChanged
AvailableLayoutInfo
PluginConfigurationChanged
HighlightClicked
InitialKeybinds
Initial keybindings sent once on plugin load and on reconfiguration. Plugins that subscribe to this event signal they cache keybindings and can handle lightweight ModeUpdate events without keybindings.