pub struct PaneInfo {Show 25 fields
pub id: u32,
pub is_plugin: bool,
pub is_focused: bool,
pub is_fullscreen: bool,
pub is_floating: bool,
pub is_suppressed: bool,
pub title: String,
pub exited: bool,
pub exit_status: Option<i32>,
pub is_held: bool,
pub pane_x: usize,
pub pane_content_x: usize,
pub pane_y: usize,
pub pane_content_y: usize,
pub pane_rows: usize,
pub pane_content_rows: usize,
pub pane_columns: usize,
pub pane_content_columns: usize,
pub cursor_coordinates_in_pane: Option<(usize, usize)>,
pub terminal_command: Option<String>,
pub plugin_url: Option<String>,
pub is_selectable: bool,
pub index_in_pane_group: BTreeMap<ClientId, usize>,
pub default_fg: Option<String>,
pub default_bg: Option<String>,
}Expand description
Contains all the information for a currently open pane
Difference between coordinates/size and content coordinates/size
The pane basic coordinates and size (eg. pane_x or pane_columns) are the entire space taken
up by this pane - including its frame and title if it has a border.
The pane content coordinates and size (eg. pane_content_x or pane_content_columns)
represent the area taken by the pane’s content, excluding its frame and title if it has a
border.
Fields
id: u32The id of the pane, unique to all panes of this kind (eg. id in terminals or id in panes)
is_plugin: boolWhether this pane is a plugin (true) or a terminal (false), used along with id can represent a unique pane ID across
the running session
is_focused: boolWhether the pane is focused in its layer (tiled or floating)
is_fullscreen: boolis_floating: boolWhether a pane is floating or tiled (embedded)
is_suppressed: boolWhether a pane is suppressed - suppressed panes are not visible to the user, but still run in the background
title: StringThe full title of the pane as it appears in the UI (if there is room for it)
exited: boolWhether a pane exited or not, note that most panes close themselves before setting this flag, so this is only relevant to command panes
exit_status: Option<i32>The exit status of a pane if it did exit and is still in the UI
is_held: boolA “held” pane is a paused pane that is waiting for user input (eg. a command pane that exited and is waiting to be re-run or closed)
pane_x: usizepane_content_x: usizepane_y: usizepane_content_y: usizepane_rows: usizepane_content_rows: usizepane_columns: usizepane_content_columns: usizecursor_coordinates_in_pane: Option<(usize, usize)>The coordinates of the cursor - if this pane is focused - relative to the pane’s coordinates
terminal_command: Option<String>If this is a command pane, this will show the stringified version of the command and its arguments
plugin_url: Option<String>The URL from which this plugin was loaded (eg. zellij:strider for the built-in strider
plugin or file:/path/to/my/plugin.wasm for a local plugin)
is_selectable: boolUnselectable panes are often used for UI elements that do not have direct user interaction
(eg. the default status-bar or tab-bar).
index_in_pane_group: BTreeMap<ClientId, usize>Grouped panes (usually through an explicit user action) that are staged for a bulk action the index is kept track of in order to preserve the pane group order
default_fg: Option<String>The default foreground color of this pane, if set (e.g. “#00e000”)
default_bg: Option<String>The default background color of this pane, if set (e.g. “#001a3a”)
Implementations
Sourceimpl PaneInfo
impl PaneInfo
pub fn decode_from_kdl( kdl_document: &KdlDocument, ) -> Result<(usize, Self), String>
pub fn encode_to_kdl(&self) -> KdlDocument