pub struct TabInfo {Show 19 fields
pub position: usize,
pub name: String,
pub active: bool,
pub panes_to_hide: usize,
pub is_fullscreen_active: bool,
pub is_sync_panes_active: bool,
pub are_floating_panes_visible: bool,
pub other_focused_clients: Vec<ClientId>,
pub active_swap_layout_name: Option<String>,
pub is_swap_layout_dirty: bool,
pub viewport_rows: usize,
pub viewport_columns: usize,
pub display_area_rows: usize,
pub display_area_columns: usize,
pub selectable_tiled_panes_count: usize,
pub selectable_floating_panes_count: usize,
pub tab_id: usize,
pub has_bell_notification: bool,
pub is_flashing_bell: bool,
}Expand description
Contains all the information for a currently opened tab.
Fields
position: usizeThe Tab’s 0 indexed position
name: StringThe name of the tab as it appears in the UI (if there’s enough room for it)
active: boolWhether this tab is focused
panes_to_hide: usizeThe number of suppressed panes this tab has
is_fullscreen_active: boolWhether there’s one pane taking up the whole display area on this tab
is_sync_panes_active: boolWhether input sent to this tab will be synced to all panes in it
are_floating_panes_visible: boolother_focused_clients: Vec<ClientId>active_swap_layout_name: Option<String>is_swap_layout_dirty: boolWhether the user manually changed the layout, moving out of the swap layout scheme
viewport_rows: usizeRow count in the viewport (including all non-ui panes, eg. will excluse the status bar)
viewport_columns: usizeColumn count in the viewport (including all non-ui panes, eg. will excluse the status bar)
display_area_rows: usizeRow count in the display area (including all panes, will typically be larger than the viewport)
display_area_columns: usizeColumn count in the display area (including all panes, will typically be larger than the viewport)
selectable_tiled_panes_count: usizeThe number of selectable (eg. not the UI bars) tiled panes currently in this tab
selectable_floating_panes_count: usizeThe number of selectable (eg. not the UI bars) floating panes currently in this tab
tab_id: usizeThe stable identifier for this tab
has_bell_notification: boolWhether this tab has an active (persistent) bell notification
is_flashing_bell: boolWhether this tab is currently flashing its bell (transient 400ms state)
Implementations
Sourceimpl TabInfo
impl TabInfo
pub fn decode_from_kdl(kdl_document: &KdlDocument) -> Result<Self, String>
pub fn encode_to_kdl(&self) -> KdlDocument