pub struct MouseEvent {
pub event_type: MouseEventType,
pub left: bool,
pub right: bool,
pub middle: bool,
pub wheel_up: bool,
pub wheel_down: bool,
pub shift: bool,
pub alt: bool,
pub ctrl: bool,
pub position: Position,
}Expand description
A mouse event can have any number of buttons (including no buttons) pressed or released.
Fields
event_type: MouseEventTypeA mouse event can current be a Press, Release, or Motion. Future events could consider double-click and triple-click.
left: boolright: boolmiddle: boolwheel_up: boolwheel_down: boolshift: boolalt: boolctrl: boolposition: PositionThe coordinates are zero-based.
Implementations
Sourceimpl MouseEvent
impl MouseEvent
pub fn new() -> Self
pub fn new_left_press_event(position: Position) -> Self
pub fn new_right_press_event(position: Position) -> Self
pub fn new_middle_press_event(position: Position) -> Self
pub fn new_middle_release_event(position: Position) -> Self
pub fn new_left_release_event(position: Position) -> Self
pub fn new_left_motion_event(position: Position) -> Self
pub fn new_right_release_event(position: Position) -> Self
pub fn new_right_motion_event(position: Position) -> Self
pub fn new_middle_motion_event(position: Position) -> Self
pub fn new_left_press_with_alt_event(position: Position) -> Self
pub fn new_right_press_with_alt_event(position: Position) -> Self
pub fn new_left_press_with_ctrl_event(position: Position) -> Self
pub fn new_left_motion_with_ctrl_event(position: Position) -> Self
pub fn new_left_release_with_ctrl_event(position: Position) -> Self
pub fn new_left_motion_with_alt_event(position: Position) -> Self
pub fn new_scroll_up_event(position: Position) -> Self
pub fn new_scroll_down_event(position: Position) -> Self
pub fn new_ctrl_scroll_up_event(position: Position) -> Self
pub fn new_ctrl_scroll_down_event(position: Position) -> Self