Options

Struct Options 

pub struct Options {
Show 45 fields pub simplified_ui: Option<bool>, pub theme: Option<String>, pub default_mode: Option<InputMode>, pub default_shell: Option<PathBuf>, pub default_cwd: Option<PathBuf>, pub default_layout: Option<PathBuf>, pub layout_dir: Option<PathBuf>, pub theme_dir: Option<PathBuf>, pub mouse_mode: Option<bool>, pub pane_frames: Option<bool>, pub mirror_session: Option<bool>, pub on_force_close: Option<OnForceClose>, pub scroll_buffer_size: Option<usize>, pub copy_command: Option<String>, pub copy_clipboard: Option<Clipboard>, pub copy_on_select: Option<bool>, pub osc8_hyperlinks: Option<bool>, pub scrollback_editor: Option<PathBuf>, pub session_name: Option<String>, pub attach_to_session: Option<bool>, pub auto_layout: Option<bool>, pub session_serialization: Option<bool>, pub serialize_pane_viewport: Option<bool>, pub scrollback_lines_to_serialize: Option<usize>, pub styled_underlines: Option<bool>, pub serialization_interval: Option<u64>, pub disable_session_metadata: Option<bool>, pub support_kitty_keyboard_protocol: Option<bool>, pub web_server: Option<bool>, pub web_sharing: Option<WebSharing>, pub stacked_resize: Option<bool>, pub show_startup_tips: Option<bool>, pub show_release_notes: Option<bool>, pub advanced_mouse_actions: Option<bool>, pub mouse_hover_effects: Option<bool>, pub visual_bell: Option<bool>, pub focus_follows_mouse: Option<bool>, pub mouse_click_through: Option<bool>, pub web_server_ip: Option<IpAddr>, pub web_server_port: Option<u16>, pub web_server_cert: Option<PathBuf>, pub web_server_key: Option<PathBuf>, pub enforce_https_for_localhost: Option<bool>, pub post_command_discovery_hook: Option<String>, pub client_async_worker_tasks: Option<usize>,
}
Options that can be set either through the config file, or cli flags - cli flags should take precedence over the config file TODO: In order to correctly parse boolean flags, this is currently split into Options and CliOptions, this could be a good canditate for a macro

Fields

simplified_ui: Option<bool>

Allow plugins to use a more simplified layout that is compatible with more fonts (true or false)

theme: Option<String>

Set the default theme

default_mode: Option<InputMode>

Set the default mode

default_shell: Option<PathBuf>

Set the default shell

default_cwd: Option<PathBuf>

Set the default cwd

default_layout: Option<PathBuf>

Set the default layout

layout_dir: Option<PathBuf>

Set the layout_dir, defaults to subdirectory of config dir

theme_dir: Option<PathBuf>

Set the theme_dir, defaults to subdirectory of config dir

mouse_mode: Option<bool>

Set the handling of mouse events (true or false) Can be temporarily bypassed by the [SHIFT] key

pane_frames: Option<bool>

Set display of the pane frames (true or false)

mirror_session: Option<bool>

Mirror session when multiple users are connected (true or false)

on_force_close: Option<OnForceClose>

Set behaviour on force close (quit or detach)

scroll_buffer_size: Option<usize>copy_command: Option<String>

Switch to using a user supplied command for clipboard instead of OSC52

copy_clipboard: Option<Clipboard>

OSC52 destination clipboard

copy_on_select: Option<bool>

Automatically copy when selecting text (true or false)

osc8_hyperlinks: Option<bool>

Enable OSC8 hyperlink output (true or false)

scrollback_editor: Option<PathBuf>

Explicit full path to open the scrollback editor (default is $EDITOR or $VISUAL)

session_name: Option<String>

The name of the session to create when starting Zellij

attach_to_session: Option<bool>

Whether to attach to a session specified in “session-name” if it exists

auto_layout: Option<bool>

Whether to lay out panes in a predefined set of layouts whenever possible

session_serialization: Option<bool>

Whether sessions should be serialized to the HD so that they can be later resurrected, default is true

serialize_pane_viewport: Option<bool>

Whether pane viewports are serialized along with the session, default is false

scrollback_lines_to_serialize: Option<usize>

Scrollback lines to serialize along with the pane viewport when serializing sessions, 0 defaults to the scrollback size. If this number is higher than the scrollback size, it will also default to the scrollback size

styled_underlines: Option<bool>

Whether to use ANSI styled underlines

serialization_interval: Option<u64>

The interval at which to serialize sessions for resurrection (in seconds)

disable_session_metadata: Option<bool>

If true, will disable writing session metadata to disk

support_kitty_keyboard_protocol: Option<bool>

Whether to enable support for the Kitty keyboard protocol (must also be supported by the host terminal), defaults to true if the terminal supports it

web_server: Option<bool>

Whether to make sure a local web server is running when a new Zellij session starts. This web server will allow creating new sessions and attaching to existing ones that have opted in to being shared in the browser.

Note: a local web server can still be manually started from within a Zellij session or from the CLI. If this is not desired, one can use a version of Zellij compiled without web_server_capability

Possible values:

  • true
  • false Default: false
web_sharing: Option<WebSharing>

Whether to allow new sessions to be shared through a local web server, assuming one is running (see the web_server option for more details).

Note: if Zellij was compiled without web_server_capability, this option will be locked to “disabled”

Possible values:

  • “on” (new sessions will allow web sharing through the local web server if it is online)
  • “off” (new sessions will not allow web sharing unless they explicitly opt-in to it)
  • “disabled” (new sessions will not allow web sharing and will not be able to opt-in to it) Default: “off”
stacked_resize: Option<bool>

Whether to stack panes when resizing beyond a certain size default is true

show_startup_tips: Option<bool>

Whether to show startup tips when starting a new session default is true

show_release_notes: Option<bool>

Whether to show release notes on first run of a new version default is true

advanced_mouse_actions: Option<bool>

Whether to enable mouse hover effects and pane grouping functionality default is true

mouse_hover_effects: Option<bool>

Whether to enable mouse hover visual effects (frame highlight and help text) default is true

visual_bell: Option<bool>

Whether to show visual bell indicators (pane/tab frame flash and ! suffix) default is true

focus_follows_mouse: Option<bool>

Whether to focus panes on mouse hover (true or false) default is false

mouse_click_through: Option<bool>

Whether clicking a pane to focus it also sends the click into the pane (true or false) default is false

web_server_ip: Option<IpAddr>web_server_port: Option<u16>web_server_cert: Option<PathBuf>web_server_key: Option<PathBuf>enforce_https_for_localhost: Option<bool>post_command_discovery_hook: Option<String>

A command to run after the discovery of running commands when serializing, for the purpose of manipulating the command (eg. with a regex) before it gets serialized

client_async_worker_tasks: Option<usize>

Number of async worker tasks to spawn per active client.

Allocating few tasks may result in resource contention and lags. Small values (around 4) should typically work best. Set to 0 to use the number of (physical) CPU cores. NOTE: This only applies to web clients at the moment.

Implementations

Source

impl Options

pub fn from_yaml(from_yaml: Option<Options>) -> Options

pub fn merge(&self, other: Options) -> Options

Merges two Options structs, a Some in other will supersede a Some in self

pub fn merge_from_cli(&self, other: Options) -> Options

Merges two Options structs,

  • Some in other will supersede a Some in self
  • Some(bool) in other will toggle a Some(bool) in self
pub fn from_cli(&self, other: Option<Command>) -> Options

Source

impl Options

pub fn from_kdl(kdl_options: &KdlDocument) -> Result<Self, ConfigError>

pub fn from_string( stringified_keybindings: &String, ) -> Result<Self, ConfigError>

pub fn to_kdl(&self, add_comments: bool) -> Vec<KdlNode>