pub struct PluginConfig {
pub path: PathBuf,
pub _allow_exec_host_cmd: bool,
pub location: RunPluginLocation,
pub initial_userspace_configuration: PluginUserConfiguration,
pub initial_cwd: Option<PathBuf>,
}Expand description
Plugin metadata
Fields
path: PathBufPath of the plugin, see resolve_wasm_bytes for resolution semantics
_allow_exec_host_cmd: boolAllow command execution from plugin
location: RunPluginLocationOriginal location of the
initial_userspace_configuration: PluginUserConfigurationCustom configuration for this plugin
initial_cwd: Option<PathBuf>plugin initial working directory
Implementations
Sourceimpl PluginConfig
impl PluginConfig
pub fn from_run_plugin(run_plugin: &RunPlugin) -> Option<PluginConfig>
Sourcepub fn resolve_wasm_bytes(&self, plugin_dir: &Path) -> Result<Vec<u8>>
pub fn resolve_wasm_bytes(&self, plugin_dir: &Path) -> Result<Vec<u8>>
Resolve wasm plugin bytes for the plugin path and given plugin directory.
If zellij was built without the ‘disable_automatic_asset_installation’ feature, builtin plugins (Starting with ‘zellij:’ in the layout file) are loaded directly from the binary-internal asset map. Otherwise:
Attempts to first resolve the plugin path as an absolute path, then adds a “.wasm” extension to the path and resolves that, then the plugin directory joined with the path with an appended “.wasm” extension, and finally the system data directory joined with “plugins” and the same file name. So if our path is “tab-bar” and the given plugin dir is “/home/bob/.local/share/zellij/plugins” the lookup chain will be this:
tab-bar
tab-bar.wasm
/home/bob/.local/share/zellij/plugins/tab-bar.wasm
/usr/share/zellij/plugins/tab-bar.wasmpub fn is_builtin(&self) -> bool
pub fn is_builtin_name(&self) -> bool