Module action

Module action 

Modules

action
Nested message and enum types in Action.
command_or_plugin
Nested message and enum types in CommandOrPlugin.
new_pane_placement
Nested message and enum types in NewPanePlacement.
pane_id
Nested message and enum types in PaneId.
pane_run
Nested message and enum types in PaneRun.
percent_or_fixed
Nested message and enum types in PercentOrFixed.
run_plugin_location_data
Nested message and enum types in RunPluginLocationData.
run_plugin_or_alias
Nested message and enum types in RunPluginOrAlias.
split_size
Nested message and enum types in SplitSize.

Structs

Action
AreFloatingPanesVisiblePayload
CliPipePayload
CommandOrPlugin
CommandOrPluginFile
DumpScreenPayload
EditFilePayload
FloatingPaneCoordinates
FloatingPaneCoordinates specifies the position and size of a floating pane
FloatingPaneLayout
FloatingPlacement
GoToTabNamePayload
HideFloatingPanesPayload
IdAndName
InPlaceConfig
KeyWithModifier
LaunchOrFocusPluginPayload
LayoutConstraintFloatingPair
LayoutConstraintTiledPair
LayoutConstraintWithValue
MouseEventPayload
MovePanePayload
NameAndValue
NewBlockingPanePayload
NewFloatingPanePayload
NewInPlacePanePayload
NewPanePayload
NewPanePlacement
NewPanePlacement specifies where a new pane should be placed
NewPluginPanePayload
NewTabPayload
NewTiledPanePayload
NoPreferenceOptions
OverrideLayoutPayload
PaneId
PaneId identifies either a terminal or plugin pane
PaneIdAndShouldFloat
PaneRun
PercentOrFixed
PluginAlias
PluginConfiguration
PluginTag
PluginUserConfiguration
Position
RunCommandAction
RunEditFileAction
RunPlugin
RunPluginLocationData
RunPluginOrAlias
ScrollAtPayload
SetPaneBorderlessPayload
SetPaneBorderlessPayload specifies the pane and borderless state
ShowFloatingPanesPayload
SplitSize
SplitSize represents a dimension that can be either a percentage or fixed size
StackedPlacement
SwapFloatingLayout
SwapTiledLayout
SwitchToModePayload
TabIdAndName
TabLayoutInfo
TiledPaneLayout
TiledPlacement
WriteCharsPayload
WritePayload

Enums

ActionName
BareKey
KeyModifier
LayoutConstraint
MoveTabDirection
RunPluginLocation
SearchDirection
SearchOption
SplitDirection
UnblockCondition
UnblockCondition specifies when a blocking pane should unblock