pub struct FloatingPaneLayout {
pub name: Option<String>,
pub height: Option<PercentOrFixed>,
pub width: Option<PercentOrFixed>,
pub x: Option<PercentOrFixed>,
pub y: Option<PercentOrFixed>,
pub pinned: Option<bool>,
pub run: Option<PaneRun>,
pub focus: Option<bool>,
pub already_running: bool,
pub pane_initial_contents: Option<String>,
pub logical_position: Option<u32>,
pub borderless: Option<bool>,
}Fields
name: Option<String>height: Option<PercentOrFixed>width: Option<PercentOrFixed>x: Option<PercentOrFixed>y: Option<PercentOrFixed>pinned: Option<bool>run: Option<PaneRun>focus: Option<bool>already_running: boolpane_initial_contents: Option<String>logical_position: Option<u32>borderless: Option<bool>Implementations
Sourceimpl FloatingPaneLayout
impl FloatingPaneLayout
Sourcepub fn pinned(&self) -> bool
pub fn pinned(&self) -> bool
Returns the value of pinned, or the default value if pinned is unset.
Sourcepub fn focus(&self) -> bool
pub fn focus(&self) -> bool
Returns the value of focus, or the default value if focus is unset.
Sourcepub fn pane_initial_contents(&self) -> &str
pub fn pane_initial_contents(&self) -> &str
Returns the value of pane_initial_contents, or the default value if pane_initial_contents is unset.
Sourcepub fn logical_position(&self) -> u32
pub fn logical_position(&self) -> u32
Returns the value of logical_position, or the default value if logical_position is unset.
Sourcepub fn borderless(&self) -> bool
pub fn borderless(&self) -> bool
Returns the value of borderless, or the default value if borderless is unset.