pub struct KeyWithModifier {
pub bare_key: i32,
pub key_modifiers: Vec<i32>,
pub character: Option<String>,
}Fields
bare_key: i32key_modifiers: Vec<i32>character: Option<String>Only set when bare_key is CHAR
Implementations
Sourceimpl KeyWithModifier
impl KeyWithModifier
Sourcepub fn bare_key(&self) -> BareKey
pub fn bare_key(&self) -> BareKey
Returns the enum value of bare_key, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bare_key(&mut self, value: BareKey)
pub fn set_bare_key(&mut self, value: BareKey)
Sets bare_key to the provided enum value.
Sourcepub fn key_modifiers(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KeyModifier>>
pub fn key_modifiers( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<KeyModifier>>
Returns an iterator which yields the valid enum values contained in key_modifiers.
Sourcepub fn push_key_modifiers(&mut self, value: KeyModifier)
pub fn push_key_modifiers(&mut self, value: KeyModifier)
Appends the provided enum value to key_modifiers.