pub struct TiledPaneLayout {Show 13 fields
pub children_split_direction: i32,
pub name: Option<String>,
pub children: Vec<TiledPaneLayout>,
pub split_size: Option<SplitSize>,
pub run: Option<PaneRun>,
pub borderless: bool,
pub focus: Option<String>,
pub exclude_from_sync: Option<bool>,
pub children_are_stacked: bool,
pub external_children_index: Option<u32>,
pub is_expanded_in_stack: bool,
pub hide_floating_panes: bool,
pub pane_initial_contents: Option<String>,
}Fields
children_split_direction: i32name: Option<String>children: Vec<TiledPaneLayout>split_size: Option<SplitSize>run: Option<PaneRun>borderless: boolfocus: Option<String>exclude_from_sync: Option<bool>children_are_stacked: boolexternal_children_index: Option<u32>is_expanded_in_stack: boolhide_floating_panes: boolpane_initial_contents: Option<String>Implementations
Sourceimpl TiledPaneLayout
impl TiledPaneLayout
Sourcepub fn children_split_direction(&self) -> SplitDirection
pub fn children_split_direction(&self) -> SplitDirection
Returns the enum value of children_split_direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_children_split_direction(&mut self, value: SplitDirection)
pub fn set_children_split_direction(&mut self, value: SplitDirection)
Sets children_split_direction to the provided enum value.
Sourcepub fn focus(&self) -> &str
pub fn focus(&self) -> &str
Returns the value of focus, or the default value if focus is unset.
Sourcepub fn exclude_from_sync(&self) -> bool
pub fn exclude_from_sync(&self) -> bool
Returns the value of exclude_from_sync, or the default value if exclude_from_sync is unset.
Sourcepub fn external_children_index(&self) -> u32
pub fn external_children_index(&self) -> u32
Returns the value of external_children_index, or the default value if external_children_index is unset.
Sourcepub fn pane_initial_contents(&self) -> &str
pub fn pane_initial_contents(&self) -> &str
Returns the value of pane_initial_contents, or the default value if pane_initial_contents is unset.