pub struct OpenCommandPaneResponse {
pub pane_id: Option<PaneId>,
}Fields
pane_id: Option<PaneId>Trait Implementations
Sourceimpl Clone for OpenCommandPaneResponse
impl Clone for OpenCommandPaneResponse
Sourcefn clone(&self) -> OpenCommandPaneResponse
fn clone(&self) -> OpenCommandPaneResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenCommandPaneResponse
impl Debug for OpenCommandPaneResponse
Sourceimpl Default for OpenCommandPaneResponse
impl Default for OpenCommandPaneResponse
Sourceimpl From<Option<PaneId>> for ProtobufOpenCommandPaneResponse
impl From<Option<PaneId>> for ProtobufOpenCommandPaneResponse
Sourcefn from(response: OpenCommandPaneResponse) -> Self
fn from(response: OpenCommandPaneResponse) -> Self
Converts to this type from the input type.
Sourceimpl Message for OpenCommandPaneResponse
impl Message for OpenCommandPaneResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OpenCommandPaneResponse
impl PartialEq for OpenCommandPaneResponse
impl StructuralPartialEq for OpenCommandPaneResponse