pub enum CliAction {
Show 72 variants
Write {
bytes: Vec<u8>,
pane_id: Option<String>,
},
WriteChars {
chars: String,
pane_id: Option<String>,
},
Paste {
chars: String,
pane_id: Option<String>,
},
SendKeys {
keys: Vec<String>,
pane_id: Option<String>,
},
Resize {
resize: Resize,
direction: Option<Direction>,
pane_id: Option<String>,
},
FocusNextPane,
FocusPreviousPane,
FocusPaneId {
pane_id: String,
},
MoveFocus {
direction: Direction,
},
MoveFocusOrTab {
direction: Direction,
},
MovePane {
direction: Option<Direction>,
pane_id: Option<String>,
},
MovePaneBackwards {
pane_id: Option<String>,
},
Clear {
pane_id: Option<String>,
},
DumpScreen {
path: Option<PathBuf>,
full: bool,
pane_id: Option<String>,
ansi: bool,
},
DumpLayout,
SaveSession,
EditScrollback {
pane_id: Option<String>,
ansi: bool,
},
ScrollUp {
pane_id: Option<String>,
},
ScrollDown {
pane_id: Option<String>,
},
ScrollToBottom {
pane_id: Option<String>,
},
ScrollToTop {
pane_id: Option<String>,
},
PageScrollUp {
pane_id: Option<String>,
},
PageScrollDown {
pane_id: Option<String>,
},
HalfPageScrollUp {
pane_id: Option<String>,
},
HalfPageScrollDown {
pane_id: Option<String>,
},
ToggleFullscreen {
pane_id: Option<String>,
},
TogglePaneFrames,
ToggleActiveSyncTab {
tab_id: Option<usize>,
},
NewPane {Show 26 fields
direction: Option<Direction>,
command: Vec<String>,
plugin: Option<String>,
cwd: Option<PathBuf>,
floating: bool,
in_place: bool,
close_replaced_pane: bool,
name: Option<String>,
close_on_exit: bool,
start_suspended: bool,
configuration: Option<PluginUserConfiguration>,
skip_plugin_cache: bool,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
stacked: bool,
blocking: bool,
block_until_exit_success: bool,
block_until_exit_failure: bool,
block_until_exit: bool,
unblock_condition: Option<UnblockCondition>,
near_current_pane: bool,
borderless: Option<bool>,
tab_id: Option<usize>,
},
Edit {Show 15 fields
file: PathBuf,
direction: Option<Direction>,
line_number: Option<usize>,
floating: bool,
in_place: bool,
close_replaced_pane: bool,
cwd: Option<PathBuf>,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
near_current_pane: bool,
borderless: Option<bool>,
tab_id: Option<usize>,
},
SwitchMode {
input_mode: InputMode,
},
TogglePaneEmbedOrFloating {
pane_id: Option<String>,
},
ToggleFloatingPanes {
tab_id: Option<usize>,
},
ShowFloatingPanes {
tab_id: Option<usize>,
},
HideFloatingPanes {
tab_id: Option<usize>,
},
AreFloatingPanesVisible {
tab_id: Option<usize>,
},
ClosePane {
pane_id: Option<String>,
},
RenamePane {
name: String,
pane_id: Option<String>,
},
UndoRenamePane {
pane_id: Option<String>,
},
GoToNextTab,
GoToPreviousTab,
CloseTab {
tab_id: Option<usize>,
},
GoToTab {
index: u32,
},
GoToTabName {
name: String,
create: bool,
},
RenameTab {
name: String,
tab_id: Option<usize>,
},
UndoRenameTab {
tab_id: Option<usize>,
},
GoToTabById {
id: u64,
},
CloseTabById {
id: u64,
},
RenameTabById {
id: u64,
name: String,
},
NewTab {
layout: Option<PathBuf>,
layout_string: Option<String>,
layout_dir: Option<PathBuf>,
name: Option<String>,
cwd: Option<PathBuf>,
initial_command: Vec<String>,
initial_plugin: Option<String>,
close_on_exit: bool,
start_suspended: bool,
block_until_exit_success: bool,
block_until_exit_failure: bool,
block_until_exit: bool,
},
MoveTab {
direction: Direction,
tab_id: Option<usize>,
},
PreviousSwapLayout {
tab_id: Option<usize>,
},
NextSwapLayout {
tab_id: Option<usize>,
},
OverrideLayout {
layout: Option<PathBuf>,
layout_string: Option<String>,
layout_dir: Option<PathBuf>,
retain_existing_terminal_panes: bool,
retain_existing_plugin_panes: bool,
apply_only_to_active_tab: bool,
},
QueryTabNames,
StartOrReloadPlugin {
url: String,
configuration: Option<PluginUserConfiguration>,
},
LaunchOrFocusPlugin {
floating: bool,
in_place: bool,
close_replaced_pane: bool,
move_to_focused_tab: bool,
url: String,
configuration: Option<PluginUserConfiguration>,
skip_plugin_cache: bool,
tab_id: Option<usize>,
},
LaunchPlugin {
floating: bool,
in_place: bool,
close_replaced_pane: bool,
url: Url,
configuration: Option<PluginUserConfiguration>,
skip_plugin_cache: bool,
tab_id: Option<usize>,
},
RenameSession {
name: String,
},
Pipe {
name: Option<String>,
payload: Option<String>,
args: Option<PluginUserConfiguration>,
plugin: Option<String>,
plugin_configuration: Option<PluginUserConfiguration>,
force_launch_plugin: bool,
skip_plugin_cache: bool,
floating_plugin: Option<bool>,
in_place_plugin: Option<bool>,
plugin_cwd: Option<PathBuf>,
plugin_title: Option<String>,
},
ListClients,
ListPanes {
tab: bool,
command: bool,
state: bool,
geometry: bool,
all: bool,
json: bool,
},
ListTabs {
state: bool,
dimensions: bool,
panes: bool,
layout: bool,
all: bool,
json: bool,
},
CurrentTabInfo {
json: bool,
},
TogglePanePinned {
pane_id: Option<String>,
},
StackPanes {
pane_ids: Vec<String>,
},
ChangeFloatingPaneCoordinates {
pane_id: String,
x: Option<String>,
y: Option<String>,
width: Option<String>,
height: Option<String>,
pinned: Option<bool>,
borderless: Option<bool>,
},
TogglePaneBorderless {
pane_id: String,
},
SetPaneBorderless {
pane_id: String,
borderless: bool,
},
Detach,
SwitchSession {
name: String,
tab_position: Option<usize>,
pane_id: Option<String>,
layout: Option<PathBuf>,
layout_string: Option<String>,
layout_dir: Option<PathBuf>,
cwd: Option<PathBuf>,
},
SetPaneColor {
pane_id: Option<String>,
fg: Option<String>,
bg: Option<String>,
reset: bool,
},
}Variants
Write
Write bytes to the terminal.
Fields
WriteChars
Write characters to the terminal.
Fields
Paste
Paste text to the terminal (using bracketed paste mode).
Fields
SendKeys
Send one or more keys to the terminal (e.g., “Ctrl a”, “F1”, “Alt Shift b”)
Fields
Resize
[increase|decrease] the focused panes area at the [left|down|up|right] border.
Fields
FocusNextPane
Change focus to the next pane
FocusPreviousPane
Change focus to the previous pane
FocusPaneId
Focus a specific pane by its ID
MoveFocus
Move the focused pane in the specified direction. [right|left|up|down]
MoveFocusOrTab
Move focus to the pane or tab (if on screen edge) in the specified direction [right|left|up|down]
MovePane
Change the location of the focused pane in the specified direction or rotate forwrads [right|left|up|down]
Fields
MovePaneBackwards
Rotate the location of the previous pane backwards
Clear
Clear all buffers for a focused pane
DumpScreen
Dumps the viewport and optionally scrollback of a pane to a file or STDOUT
Fields
DumpLayout
Dump current layout to stdout
SaveSession
Save the current session state to disk immediately
EditScrollback
Open the pane scrollback in your default editor
Fields
ScrollUp
Scroll up in the focused pane
ScrollDown
Scroll down in focus pane.
ScrollToBottom
Scroll down to bottom in focus pane.
ScrollToTop
Scroll up to top in focus pane.
PageScrollUp
Scroll up one page in focus pane.
PageScrollDown
Scroll down one page in focus pane.
HalfPageScrollUp
Scroll up half page in focus pane.
HalfPageScrollDown
Scroll down half page in focus pane.
ToggleFullscreen
Toggle between fullscreen focus pane and normal layout.
TogglePaneFrames
Toggle frames around panes in the UI
ToggleActiveSyncTab
Toggle between sending text commands to all panes on the current tab and normal mode.
NewPane
Open a new pane in the specified direction [right|down]
If no direction is specified, will try to use the biggest available space.
Returns: Created pane ID (format: terminal_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
configuration: Option<PluginUserConfiguration>x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
height: Option<String>The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
block_until_exit_success: boolBlock until the command exits successfully (exit status 0) OR its pane has been closed
block_until_exit_failure: boolBlock until the command exits with failure (non-zero exit status) OR its pane has been closed
block_until_exit: boolBlock until the command exits (regardless of exit status) OR its pane has been closed
unblock_condition: Option<UnblockCondition>near_current_pane: boolif set, will open the pane near the current one rather than following the user’s focus
Edit
Open the specified file in a new zellij pane with your default EDITOR
Returns: Created pane ID (format: terminal_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
height: Option<String>The height if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
near_current_pane: boolif set, will open the pane near the current one rather than following the user’s focus
SwitchMode
Switch input mode of all connected clients [locked|pane|tab|resize|move|search|session]
TogglePaneEmbedOrFloating
Embed focused pane if floating or float focused pane if embedded
ToggleFloatingPanes
Toggle the visibility of all floating panes in the current Tab, open one if none exist
ShowFloatingPanes
Show all floating panes in the specified tab (or active tab if tab_id is not provided).
Returns exit code 0 if state was changed, 2 if already visible, 1 if tab not found.
HideFloatingPanes
Hide all floating panes in the specified tab (or active tab if tab_id is not provided).
Returns exit code 0 if state was changed, 2 if already hidden, 1 if tab not found.
AreFloatingPanesVisible
Check if floating panes are visible in the specified tab (or active tab).
Prints “true” to stdout and exits 0 if visible. Prints “false” to stdout and exits 1 if not visible.
ClosePane
Close the focused pane.
RenamePane
Renames the focused pane
Fields
UndoRenamePane
Remove a previously set pane name
GoToNextTab
Go to the next tab.
GoToPreviousTab
Go to the previous tab.
CloseTab
Close the current tab.
GoToTab
Go to tab with index [index]
GoToTabName
Go to tab with name [name]
Returns: When –create is used and tab is created, outputs the tab ID as a single number
RenameTab
Renames the focused pane
UndoRenameTab
Remove a previously set tab name
GoToTabById
Go to tab with stable ID
CloseTabById
Close tab with stable ID
RenameTabById
Rename tab by stable ID
NewTab
Create a new tab, optionally with a specified tab layout and name
Returns: The created tab’s ID as a single number on stdout
Fields
block_until_exit_success: boolBlock until the command exits successfully (exit status 0) OR its pane has been closed
MoveTab
Move the focused tab in the specified direction. [right|left]
PreviousSwapLayout
NextSwapLayout
OverrideLayout
Override the layout of the active tab
Fields
retain_existing_terminal_panes: boolRetain existing terminal panes that do not fit in the layout (default: false)
QueryTabNames
Query all tab names
StartOrReloadPlugin
LaunchOrFocusPlugin
Returns: Plugin pane ID (format: plugin_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
configuration: Option<PluginUserConfiguration>LaunchPlugin
Returns: Plugin pane ID (format: plugin_
Fields
close_replaced_pane: boolClose the replaced pane instead of suspending it (only effective with –in-place)
configuration: Option<PluginUserConfiguration>RenameSession
Pipe
Send data to one or more plugins, launch them if they are not running.
Fields
args: Option<PluginUserConfiguration>The args of the pipe
plugin: Option<String>The plugin url (eg. file:/tmp/my-plugin.wasm) to direct this pipe to, if not specified, will be sent to all plugins, if specified and is not running, the plugin will be launched
plugin_configuration: Option<PluginUserConfiguration>The plugin configuration (note: the same plugin with different configuration is considered a different plugin for the purposes of determining the pipe destination)
floating_plugin: Option<bool>If launching a plugin, should it be floating or not, defaults to floating
ListClients
ListPanes
List all panes in the current session
Returns: Formatted list of panes (table or JSON) to stdout
Fields
ListTabs
List all tabs with their information
Returns: Tab information in table or JSON format
Fields
CurrentTabInfo
Get information about the currently active tab
Returns: Tab name and ID by default, or full info in JSON
TogglePanePinned
StackPanes
Stack pane ids
Ids are a space separated list of pane ids.
They should either be in the form of terminal_<int> (eg. terminal_1), plugin_<int> (eg.
plugin_1) or bare integers in which case they’ll be considered terminals (eg. 1 is
the equivalent of terminal_1)
Example: zellij action stack-panes – terminal_1 plugin_2 3
ChangeFloatingPaneCoordinates
Fields
pane_id: StringThe pane_id of the floating pane, eg. terminal_1, plugin_2 or 3 (equivalent to terminal_3)
x: Option<String>The x coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
y: Option<String>The y coordinates if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
width: Option<String>The width if the pane is floating as a bare integer (eg. 1) or percent (eg. 10%)
TogglePaneBorderless
Fields
SetPaneBorderless
Fields
Detach
Detach from the current session
SwitchSession
Switch to a different session
Fields
pane_id: Option<String>Optional pane ID to focus (eg. “terminal_1” for terminal pane with id 1, or “plugin_2” for plugin pane with id 2)
SetPaneColor
Set the default foreground/background color of a pane